# -*- coding: utf-8 -*-
#
#  AutoFSManager
#
#  Coded by dre (c) 2016
#  Coding idea and design by dre
#  E-Mail: dre@dreambox-tools.info
#  Support: board.dreambox-tools.info
#
# This plugin is open source but it is NOT free software.
#
# This plugin may only be distributed to and executed on hardware which
# is licensed by Dream Multimedia GmbH.
# In other words:
# It's NOT allowed to distribute any parts of this plugin or its source code in ANY way
# to hardware which is NOT licensed by Dream Multimedia GmbH.
# It's NOT allowed to execute this plugin and its source code or even parts of it in ANY way
# on hardware which is NOT licensed by Dream Multimedia GmbH.
#
# If you want to use or modify the code or parts of it,
# you have to keep MY license and inform me about the modifications by mail.

from Components.config import config, ConfigSubsection, ConfigSelection, getConfigListEntry, ConfigText, ConfigYesNo, ConfigNumber, ConfigIP, NoSave
from Components.ActionMap import *
from Components.ConfigList import ConfigListScreen
from Components.FileList import FileList
from Components.Label import Label
from Components.MultiContent import MultiContentEntryText, MultiContentEntryPixmapAlphaBlend
from Components.Pixmap import Pixmap
from Components.Sources.List import List
from Plugins.Plugin import PluginDescriptor
from Screens.HelpMenu import HelpableScreen
from Screens.InputBox import InputBox
from Screens.MessageBox import MessageBox
from Screens.Screen import Screen
from Tools.Directories import fileExists, SCOPE_CURRENT_SKIN, resolveFilename
from Tools.LoadPixmap import LoadPixmap

from enigma import eConsoleAppContainer
from os import listdir as os_listdir, path as os_path, system as os_system

def Plugins(**kwargs):
	list = [
				PluginDescriptor(
					name=_("AutoFS Manager"),
					description=_("Plugin to create and maintain automounts"),
					where = [PluginDescriptor.WHERE_MENU], fnc=menu)
			]
	return list

def menu(menuid,**kwargs):
	if menuid == "network":
		return [(_("AutoFS Manager"), main, "autofsmanager", 10)]
	else:
		return []
	
def main(session, **kwargs):
	session.open(AutoFSManagerScreen)
	

class AutoFSManagerScreen(Screen, HelpableScreen):
	skin = """
		<screen position="center,center" size="600,525" title="AutoFS Manager" >
			<widget source="autofslist" render="Listbox" position="0,0" size="600,450" scrollbarMode="showOnDemand">
				<convert type="TemplatedMultiContent">
					{"template":[
						MultiContentEntryText(pos=(230,0), size=(370,25), font=0, text=0, flags=RT_VALIGN_CENTER),
						MultiContentEntryText(pos=(230,25), size=(370,25), font=0, text=1, flags=RT_VALIGN_CENTER),
						MultiContentEntryText(pos=(230,50), size=(370,25), font=0, text=2, flags=RT_VALIGN_CENTER),
						MultiContentEntryText(pos=(0,2), size=(200,25), font=1, flags=RT_HALIGN_RIGHT|RT_VALIGN_CENTER, text=_("Mount point:")),
						MultiContentEntryText(pos=(0,27), size=(200,25), font=1, flags=RT_HALIGN_RIGHT|RT_VALIGN_CENTER, text=_("AutoFS file:")),
						MultiContentEntryText(pos=(0,52), size=(200,25), font=1, flags=RT_HALIGN_RIGHT|RT_VALIGN_CENTER, text=_("Options:")),
						],
						"fonts": [gFont("Regular",20), gFont("Regular",18)],
						"itemHeight": 75
					}
				</convert>
			</widget>
			<widget name="ButtonRed" pixmap="skin_default/buttons/button_red.png" position="0,479" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonRedText" foregroundColor="#f0f0f0" font="Regular;18" position="20,475" size="280,25" transparent="1"/>
			<widget name="ButtonGreen" pixmap="skin_default/buttons/button_green.png" position="300,479" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonGreenText" foregroundColor="#f0f0f0" font="Regular;18" position="320,475" size="280,25" transparent="1"/>
			<widget name="ButtonYellow" pixmap="skin_default/buttons/button_yellow.png" position="0,504" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonYellowText" foregroundColor="#f0f0f0" font="Regular;18" position="20,500" size="280,25" transparent="1"/>
			<widget name="ButtonBlue" pixmap="skin_default/buttons/button_blue.png" position="300,504" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonBlueText" foregroundColor="#f0f0f0" font="Regular;18" position="320,500" size="280,25" transparent="1"/>			
		</screen>"""

	def __init__(self, session, args=0):
		self.session = session
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		
		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"ok":			(self.editEntry, _("Edit entry")),
			"cancel":       (self.close, _("Close")),
		}, -1)
		
		self["ColorActions"] = HelpableActionMap(self, "ColorActions", 
		{
			"red":			(self.removeEntry, _("Remove entry")),
			"green":		(self.addEntry, _("Add entry")),
			"yellow":		(self.editEntry, _("Edit entry")),
			"blue":			(self.editAutoFSFile, _("Edit autoFS file")),
		}, -1)		

		self["ButtonRed"] = Pixmap()
		self["ButtonRedText"] = Label(_("Remove entry"))
		
		self["ButtonGreen"] = Pixmap()
		self["ButtonGreenText"] = Label(_("Add entry"))

		self["ButtonYellow"] = Pixmap()
		self["ButtonYellowText"] = Label(_("Edit entry"))

		self["ButtonBlue"] = Pixmap()
		self["ButtonBlueText"] = Label(_("Edit autoFS file"))
		
		self.entryList = []
		self["autofslist"] = List(self.entryList)

		if not fileExists("/etc/auto.master.d/merlin.autofs"):
			os_system("touch /etc/auto.master.d/merlin.autofs")

		self.readFile()

	def setButtons(self):
		if len(self.entryList)>0:
			self["ButtonRed"].show()
			self["ButtonRedText"].show()			
			self["ButtonYellow"].show()
			self["ButtonYellowText"].show()
			self["ButtonBlue"].show()
			self["ButtonBlueText"].show()
		else:
			self["ButtonRed"].hide()
			self["ButtonRedText"].hide()
			self["ButtonYellow"].hide()
			self["ButtonYellowText"].hide()
			self["ButtonBlue"].hide()
			self["ButtonBlueText"].hide()
			

	def removeEntry(self):
		if len(self.entryList) >0:
			self.autofsFileForDelete = self.entryList[self["autofslist"].index][1]
			del self.entryList[self["autofslist"].index]
			autofsFile = open("/etc/auto.master.d/merlin.autofs", "w")
	
			for i in range(len(self.entryList)):
				line = "%*s %*s %s\n" %(self.len0*-1, self.entryList[i][0], self.len1*-1, self.entryList[i][1], self.entryList[i][2])
				autofsFile.write(line)
			autofsFile.close()
		
			self.session.openWithCallback(self.removeEntryCallback, MessageBox, _("Do you want to delete the autoFS file as well?"), MessageBox.TYPE_YESNO)
		
	def removeEntryCallback(self, answer):
		if answer:
			os_system('rm %s' %(self.autofsFileForDelete))

		self.readFile()


	def editEntry(self):
		if len(self.entryList)>0:
			self.session.openWithCallback(self.writeFile, AutoMountEntryScreen, self.entryList[self["autofslist"].index], True)

	def addEntry(self):
		self.session.openWithCallback(self.writeFile, AutoMountEntryScreen, [], False)
		
	def readFile(self):
		self.entryList = []
		autofsFile = open("/etc/auto.master.d/merlin.autofs" ,"r")
		self.len0 = 0
		self.len1 = 0
		
		for line in autofsFile:
			if line[0] != "\n" and line[0] != "#":
				entry = line.split()
				if len(entry) == 2:
					self.entryList.append((entry[0],entry[1],""))
				elif len(entry) > 2:
					self.entryList.append((entry[0],entry[1],' '.join(entry[2:])))
				
				if len(entry[0])>self.len0:
					self.len0 = len(entry[0])
				if len(entry[1])>self.len1:
					self.len1 = len(entry[1])
							
		autofsFile.close()
		
		self["autofslist"].setList(self.entryList)
		self.setButtons()
		
	def writeFile(self, changedEntry=None, newEntry=False):
		if changedEntry is not None:
			if newEntry:
				self.entryList.append(changedEntry)
			else:
				self.entryList[self["autofslist"].index] = changedEntry
		
			autofsFile = open("/etc/auto.master.d/merlin.autofs", "w")
	
			for i in range(len(self.entryList)):
				line = "%*s %*s %s\n" %(self.len0*-1, self.entryList[i][0], self.len1*-1, self.entryList[i][1], self.entryList[i][2])
				autofsFile.write(line)
			autofsFile.close()
		
	def editAutoFSFile(self):
		if len(self.entryList)>0:
			file = self.entryList[self["autofslist"].index][1]
		
			if file == "/etc/auto.net" or file == "/etc/auto.network" or file == "/etc/auto.master" or file == "/etc/auto.hotplug" or file == "/etc/auto.misc" or file == "/etc/auto.smb":
				self.session.open(MessageBox, _("Edit of %s is not supported as this is a standard file provided by DMM." %(file)), MessageBox.TYPE_ERROR, timeout=4)
			else:
				self.session.open(AutoFSEntryScreen, file)
		
class AutoMountEntryScreen(Screen, ConfigListScreen, HelpableScreen):
	skin = """
		<screen position="center,center" size="600,325" title="Auto Mount Entry Editor" >
			<widget name="config" position="0,40" size="600,150" scrollbarMode="showNever"/>
			<!--widget name="ButtonRed" pixmap="skin_default/buttons/button_red.png" position="0,279" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonRedText" foregroundColor="#f0f0f0" font="Regular;18" position="20,275" size="280,25" transparent="1"/-->
			<widget name="ButtonGreen" pixmap="skin_default/buttons/button_green.png" position="300,279" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonGreenText" foregroundColor="#f0f0f0" font="Regular;18" position="320,275" size="280,25" transparent="1"/>
			<widget name="ButtonYellow" pixmap="skin_default/buttons/button_yellow.png" position="0,304" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonYellowText" foregroundColor="#f0f0f0" font="Regular;18" position="20,300" size="280,25" transparent="1"/>
			<!--widget name="ButtonBlue" pixmap="skin_default/buttons/button_blue.png" position="300,304" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonBlueText" foregroundColor="#f0f0f0" font="Regular;18" position="320,300" size="280,25" transparent="1"/-->
		</screen>"""
		
	def __init__(self, session, entry, editMode=False):
		self.session = session
		self.entry = entry
		self.editMode = editMode
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
	
		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"ok":			(self.openDirectoryBrowser, _("Select directory/file")),
			"cancel":       (self.closeEditor, _("Close without saving")),
		}, -1)
		
		self["ColorActions"] = HelpableActionMap(self, "ColorActions", 
		{
			"green":		(self.confirmChanges, _("Confirm changes")),
			"yellow":		(self.openDirectoryBrowser, _("Select directory/file")),
		}, -1)

		self["ButtonGreen"] = Pixmap()
		self["ButtonGreenText"] = Label(_("Confirm changes"))

		self["ButtonYellow"] = Pixmap()
		self["ButtonYellowText"] = Label(_("Select directory/file"))
		
		self.list = []	
		
		ConfigListScreen.__init__(self, self.list)
		
		self.buildList()		
	
	def buildList(self, ConfigElement=""):
		self.list = []
		if self.editMode:
			self.directory = NoSave(ConfigText(default = self.entry[0], fixed_size = False))
			self.autofsfile = NoSave(ConfigText(default = self.entry[1], fixed_size = False))
			self.ghost = NoSave(ConfigYesNo(default = False))
			self.timeout = NoSave(ConfigYesNo(default = False))
			self.timeoutvalue = NoSave(ConfigNumber(default=60))

			if self.entry[2] != "":
				splitentry = self.entry[2].split()
				
				for part in splitentry:
					if part == "--ghost":
						self.ghost.value = True
					elif part.startswith("--timeout"):
						self.timeout.value=True
						splittimeout = part.split("=")
						if len(splittimeout)>1:
							self.timeoutvalue.value=splittimeout[1]
		else:
			self.directory = NoSave(ConfigText(default = "", fixed_size = False))
			self.autofsfile = NoSave(ConfigText(default = "", fixed_size = False))
			self.ghost = NoSave(ConfigYesNo(default = True))
			self.timeout = NoSave(ConfigYesNo(default = True))
			self.timeoutvalue = NoSave(ConfigNumber(default=60))
		self.list.append(getConfigListEntry(_("Mount point:"), self.directory))
		self.list.append(getConfigListEntry(_("AutoFS file:"), self.autofsfile))
		self.list.append(getConfigListEntry(_("Use option ghost:"), self.ghost))
		self.list.append(getConfigListEntry(_("Use option timeout:"), self.timeout))
		if self.timeout.value:
			self.list.append(getConfigListEntry(_("Timeout value:"), self.timeoutvalue))	
				
		self.timeout.addNotifier(self.buildList, initial_call=False)	
			
		self["config"].setList(self.list)		
		
	def openDirectoryBrowser(self):
		self.index = self["config"].getCurrentIndex()
		
		if self.index == 0:
			self.session.openWithCallback(self.setEntry, FileBrowserScreen, self.directory.value + "/", False)
		
		if self.index == 1:
			self.session.openWithCallback(self.setEntry, FileBrowserScreen, "/etc", True)
		
	def setEntry(self, value=""):
		if value == "" or value is None:
			pass
		else:
			if value.endswith("/"):
				value = value[:-1]
			
			if self.index == 0:
				self.directory.value = value
		
			if self.index == 1:
				self.autofsfile.value = value
		
	def confirmChanges(self):
		self.optionstext = ""
		if self.ghost.value:
			self.optionstext += "--ghost "
		if self.timeout.value:
			self.optionstext += "--timeout=%d " %(self.timeoutvalue.value)

		if not self.editMode:
			self.close([self.directory.value, self.autofsfile.value, self.optionstext], True)
		else:
			self.close([self.directory.value, self.autofsfile.value, self.optionstext], False)
		
	def closeEditor(self):
		self.close(None)

class AutoFSEntryScreen(Screen, ConfigListScreen, HelpableScreen):
	skin = """
		<screen position="center,center" size="600,425" title="AutoFS Entry Editor" >
			<widget name="config" position="0,40" size="600,275" scrollbarMode="showNever"/>
			<!--widget name="ButtonRed" pixmap="skin_default/buttons/button_red.png" position="0,379" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonRedText" foregroundColor="#f0f0f0" font="Regular;18" position="20,375" size="280,25" transparent="1"/-->
			<widget name="ButtonGreen" pixmap="skin_default/buttons/button_green.png" position="300,379" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonGreenText" foregroundColor="#f0f0f0" font="Regular;18" position="320,375" size="280,25" transparent="1"/>
			<!--widget name="ButtonYellow" pixmap="skin_default/buttons/button_yellow.png" position="0,404" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonYellowText" foregroundColor="#f0f0f0" font="Regular;18" position="20,400" size="280,25" transparent="1"/-->
			<widget name="ButtonBlue" pixmap="skin_default/buttons/button_blue.png" position="300,404" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonBlueText" foregroundColor="#f0f0f0" font="Regular;18" position="320,400" size="280,25" transparent="1"/>
		</screen>"""
		
	def __init__(self, session, file):
		self.session = session
		self.file = file
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)	

		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"cancel":       (self.close, _("Close without saving")),
		}, -1)
		
		self["ColorActions"] = HelpableActionMap(self, "ColorActions", 
		{
			"blue":		(self.readExports, _("Get NFS shares")),
			"green":	(self.generateFile, _("Generate autofs file")),
		}, -1)

		self["ButtonGreen"] = Pixmap()
		self["ButtonGreenText"] = Label(_("Generate autofs file"))
		self["ButtonGreen"].hide()
		self["ButtonGreenText"].hide()

		self["ButtonBlue"] = Pixmap()
		self["ButtonBlueText"] = Label(_("Get NFS shares"))

		self.container = eConsoleAppContainer()
		self.appClosed_testconn = self.container.appClosed.connect(self.runFinished)
		self.dataAvail_testconn = self.container.dataAvail.connect(self.dataAvail)
		
		self.list = []	
		self.exportsList = []
		self.defaultip = [0,0,0,0]
		
		ConfigListScreen.__init__(self, self.list)
		
		self.readAutoFSfile()

	def readAutoFSfile(self):
		if fileExists(self.file):
			self.currentserverip = []
			self.currentexport = None
			self.currentmountname = None
			self.currentfstype = None
			self.currentreadonly = None
			self.currentnumberofretries = None
			self.currentsofthard = None
			self.currentlock = None
			self.currentprotocol = None
			autoFSfile = open(self.file, "r")
			
			for line in autoFSfile:
				if line[0] != "\n" and line[0] != "#" and line[0] != "+":
					entry = line.split()
					
					print "content of file is", entry
					
					self.currentmountname = entry[0]
					
					splits = entry[1].split(",")
					for splitentry in splits:
						if splitentry.startswith("-fstype"):
							fstypesplit = splitentry.split("=")
							
							if len(fstypesplit) > 1:
								self.currentfstype = fstypesplit[1]
								continue
					
						if splitentry == "ro":
							self.currentreadonly = True
							continue
						if splitentry == "rw":
							self.currentreadonly = False
							continue
						if splitentry.startswith("retry"):
							retrysplit = splitentry.split("=")
							
							if len(retrysplit)>1:
								self.currentnumberofretries = retrysplit[1]
								continue
								
						if splitentry == "soft":
							self.currentsofthard = "soft"
							continue
						if splitentry == "hard":
							self.currentsofthard = "hard"
							continue
							
						if splitentry == "lock":
							self.currentlock = True
							continue
						if splitentry == "nolock":
							self.currentlock = False
							continue
							
						if splitentry == "udp":
							self.currentprotocol = "udp"
							continue
						if splitentry == "tcp":
							self.currentprotocol = "tcp"
							continue
							
						#TODO: sync einbauen
						
					splits = entry[2].split(":")
					
					if len(splits)==2:
						if splits[0] == "":
							self.currentserverip = [0,0,0,0]
						else:
							ipsplit = splits[0].split(".")
							self.currentserverip = map(int, ipsplit)

						self.currentexport = splits[1]

			autoFSfile.close()
			
			# if we have an ip we can read the current exports
			if len(self.currentserverip)>0:
				self.readExports(self.currentserverip)
			else:
				# no ip available. let the user enter an ip first
				self.buildList()
			
		
	def buildList(self, ConfigElement=""):
		self.list = []

		self.serverip = NoSave(ConfigIP(default=self.defaultip))
		self.list.append(getConfigListEntry(_("Server IP:"), self.serverip))

		if len(self.exportsList) > 0:
			self.exports = NoSave(ConfigSelection(choices=self.exportsList))
			if self.currentmountname is not None:
				self.mountnamedefault = self.currentmountname
			else:
				self.mountnamedefault = self.exportsList[0]
				pos = self.mountnamedefault.rfind("/")
				if pos != -1:
					self.mountnamedefault = self.mountnamedefault[pos+1:]
			self.mountname = NoSave(ConfigText(default = self.mountnamedefault, fixed_size = False))
			#auto should be implemented but for now we only support nfs
			self.fstype = NoSave(ConfigSelection(default = "nfs", choices=[("nfs", _("NFS"))]))
			if self.currentreadonly is not None:
				self.readonly = NoSave(ConfigYesNo(default = self.currentreadonly))
			else: 
				self.readonly = NoSave(ConfigYesNo(default = False))
			if self.currentnumberofretries is not None:
				self.numberofretries = NoSave(ConfigNumber(default=self.currentnumberofretries))
			else:
				self.numberofretries = NoSave(ConfigNumber(default=0))
			if self.currentsofthard is not None:
				self.softhard = NoSave(ConfigSelection(default = self.currentsofthard, choices=[("soft", "soft"),("hard", "hard")]))
			else:
				self.softhard = NoSave(ConfigSelection(default = "soft", choices=[("soft", "soft"),("hard", "hard")]))
			if self.currentlock is not None:
				self.lock = NoSave(ConfigYesNo(default=self.currentlock))
			else:
				self.lock = NoSave(ConfigYesNo(default=False))
			if self.currentprotocol is not None:
				self.protocol = NoSave(ConfigSelection(default = self.currentprotocol, choices=[("udp", _("UDP")), ("tcp", _("TCP"))]))				
			else:
				self.protocol = NoSave(ConfigSelection(default = "udp", choices=[("udp", _("UDP")), ("tcp", _("TCP"))]))
	
			self.list.append(getConfigListEntry(_("NFS share:"), self.exports))
			self.list.append(getConfigListEntry(_("Mount to:"), self.mountname))
			self.list.append(getConfigListEntry(_("Filesystem type:"), self.fstype))
			self.list.append(getConfigListEntry(_("Read only:"), self.readonly))
			self.list.append(getConfigListEntry(_("Number of minutes between retries:"), self.numberofretries))
			self.list.append(getConfigListEntry(_("Timeout handling"), self.softhard))
			self.list.append(getConfigListEntry(_("Lock files on server:"), self.lock))
			self.list.append(getConfigListEntry(_("Protocol:"), self.protocol))
			
			self["ButtonGreen"].show()
			self["ButtonGreenText"].show()
		else:
			self["ButtonGreen"].hide()
			self["ButtonGreenText"].hide()
						
		self["config"].setList(self.list)	
	
	def keyRight(self):
		cur = self["config"].getCurrent()[1]
		ConfigListScreen.keyRight(self)
		if len(self.exportsList)>0:
			if cur and cur == self.exports:
				self.setMountName()
		
	def keyLeft(self):
		cur = self["config"].getCurrent()[1]
		ConfigListScreen.keyLeft(self)
		if len(self.exportsList)>0:
			if cur and cur == self.exports:
				self.setMountName()
	
	def setMountName(self):
		self.mount = self.exports.value
		print "current selection", self.mount
		pos = self.mount.rfind("/")
		if pos != -1:
			self.mountname.setValue(self.mount[pos+1:])
			
		self["config"].setList(self.list)

	def generateFile(self):
		if len(self.exportsList) == 0:
			return
			
		self.mountString = ""
		rwro = ""
		lock = ""
		if self.readonly.value:
			rwro = "ro"
		else:
			rwro = "rw"
		if self.lock.value:
			lock = "lock"
		else:
			lock = "nolock"
		
		self.mountString = "%s -fstype=%s,%s,retry=%d,%s,%s,%s %s:%s" %(self.mountname.value, self.fstype.value, rwro, self.numberofretries.value, self.softhard.value, lock, self.protocol.value, '.'.join("%d" % d for d in self.serverip.value), self.exports.value)
		
		if fileExists(self.file):
			autoFSfile = open(self.file, "w")
			
			autoFSfile.write(self.mountString)
			
			autoFSfile.close()
			
		self.close()
			
		
	def readExports(self, ipaddress = None):
		
		if ipaddress is None:
			ipaddress = self.serverip.value

		self.cmd = "showmount -e %s" %('.'.join("%d" % d for d in ipaddress))
		self.defaultip = ipaddress
		self.data = ""
		self.container.execute(self.cmd)
		
	def runFinished(self, retval):
		if retval == 0:
			self.updateList()
		
	def dataAvail(self, data):
		self.data += data
		
	def updateList(self):
		self.exportsList = []
		
		self.lines = self.data.split("\n")
		
		currentExportFound = False
		for line in self.lines:
			if line.startswith("/"):
				self.exportsList.append(line.split()[0])
				if line.split()[0] == self.currentexport:
					currentExportFound = True
					
		if not currentExportFound:
			self.exportsList.append(self.currentexport)
		
		#to remove!!!!
		self.exportsList.append("/volume1/Filme2")
		print self.exportsList
		self.buildList()
			
class FileBrowserScreen(Screen, HelpableScreen):
	skin = """
		<screen position="center,center" size="600, 425" title="File Browser">
			<widget name="filelist" position="10, 10" size="580,250" scrollbarMode="showOnDemand" />
			<!--widget name="ButtonRed" pixmap="skin_default/buttons/button_red.png" position="0,379" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonRedText" foregroundColor="#f0f0f0" font="Regular;18" position="20,375" size="280,25" transparent="1"/-->
			<widget name="ButtonGreen" pixmap="skin_default/buttons/button_green.png" position="300,379" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonGreenText" foregroundColor="#f0f0f0" font="Regular;18" position="320,375" size="280,25" transparent="1"/>
			<widget name="ButtonYellow" pixmap="skin_default/buttons/button_yellow.png" position="0,404" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonYellowText" foregroundColor="#f0f0f0" font="Regular;18" position="20,400" size="280,25" transparent="1"/>
			<widget name="ButtonBlue" pixmap="skin_default/buttons/button_blue.png" position="300,404" zPosition="10" size="15,16" transparent="1" alphatest="on" />
			<widget name="ButtonBlueText" foregroundColor="#f0f0f0" font="Regular;18" position="320,400" size="280,25" transparent="1"/>			
		</screen>"""
		
		
	def __init__(self, session, startDirectory, showFiles):
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		self.session = session	
		self.showFiles = showFiles
		self.startDirectory = startDirectory
		
		self["filelist"] = FileList(self.startDirectory, showDirectories = True, showFiles = self.showFiles, showMountpoints = True, useServiceRef = False)

		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"ok":			(self.enterDirectory, _("Enter directory")),
			"cancel":       (self.close, _("Close")),
		}, -1)
		
		self["ColorActions"] = HelpableActionMap(self, "ColorActions",
		{
			"green":		(self.selectEntry, _("Select directory/file")),
			"blue":			(self.createFile, _("Create aufoFS file")),
			"yellow":		(self.createDirectory, _("Create directory")),
		}, -1)		

		self["ButtonGreen"] = Pixmap()
		self["ButtonGreenText"] = Label(_("Select directory/file"))

		self["ButtonBlue"] = Pixmap()
		self["ButtonBlueText"] = Label(_("Create aufoFS file"))
		if not self.showFiles:
			self["ButtonBlue"].hide()
			self["ButtonBlueText"].hide()		

		self["ButtonYellow"] = Pixmap()
		self["ButtonYellowText"] = Label(_("Create directory"))

	def enterDirectory(self):
		if self["filelist"].canDescent():
			self["filelist"].descent()
			
	def selectEntry(self):
		if self["filelist"].canDescent():
			self.close(self["filelist"].getFilename())
		else:
			self.close(self["filelist"].getCurrentDirectory() + "/" + self["filelist"].getFilename())
	
	def createFile(self):
		if self.showFiles:
			self["ButtonBlue"].show()
			self["ButtonBlueText"].show()
			self.session.openWithCallback(self.createFileCallback, InputBox, title=_("Please enter the file name:"), useableChars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./_", text=self["filelist"].getCurrentDirectory())

	def createDirectory(self):
		self.session.openWithCallback(self.createDirectoryCallback, InputBox, title=_("Please enter the directory name:"), useableChars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./_", text= self["filelist"].getCurrentDirectory())
	
	def createFileCallback(self, input):
		if input is None:
			return
			
		if input == "":
			return
			
		os_system("touch %s" %(input))
		
		self["filelist"].refresh()
		
	def createDirectoryCallback(self, input):
		if input is None:
			return
			
		if input == "":
			return
			
		os_system("mkdir %s" %(input))
		
		self["filelist"].refresh()		
			
			

		
		
		